@@ -47,12 +47,12 @@ class Config:
 
     def get(self):
         if self.CONFIG_FILE.exists():
-            return pickle.load(self.CONFIG_FILE.open('rb', encoding='utf-8'))
+            return pickle.load(self.CONFIG_FILE.open('rb'))
         else:
             return {}
 
     def put(self, config):
-        pickle.dump(config, self.CONFIG_FILE.open('wb', encoding='utf-8'))
+        pickle.dump(config, self.CONFIG_FILE.open('wb'))
 
 
 class Tapd:
